@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: latin1 -*-
 
-### Copyright (C) 2011 Damon Lynch <damonlynch@gmail.com>
+### Copyright (C) 2011-2012 Damon Lynch <damonlynch@gmail.com>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -15,7 +15,8 @@
 
 ### You should have received a copy of the GNU General Public License
 ### along with this program; if not, write to the Free Software
-### Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+### Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+### USA
 
 import os
 import gtk
@@ -66,7 +67,6 @@ else:
 FILE_TYPE_PHOTO = 0
 FILE_TYPE_VIDEO = 1
 
-
 def file_type(file_extension):
     """
     Uses file extentsion to determine the type of file - photo or video.
@@ -101,6 +101,14 @@ class FileTypeCounter:
     def add(self, file_type):
         self._counter[file_type] = self._counter.setdefault(file_type, 0) + 1
         
+    def no_videos(self):
+        """Returns the number of videos"""
+        return self._counter.setdefault(FILE_TYPE_VIDEO, 0)
+        
+    def no_photos(self):
+        """Returns the number of photos"""
+        return self._counter.setdefault(FILE_TYPE_PHOTO, 0)
+        
     def file_types_present(self):
         """ 
         returns a string to be displayed to the user that can be used
@@ -108,8 +116,8 @@ class FileTypeCounter:
         of each
         """
         
-        no_videos = self._counter.setdefault(FILE_TYPE_VIDEO, 0)
-        no_images = self._counter.setdefault(FILE_TYPE_PHOTO, 0)
+        no_videos = self.no_videos()
+        no_images = self.no_photos()
         
         if (no_videos > 0) and (no_images > 0):
             v = _('photos and videos')
@@ -134,6 +142,10 @@ class FileTypeCounter:
         return i
         
     def summarize_file_count(self):
+        """
+        Summarizes the total number of photos and/or videos that can be
+        downloaded. Displayed after a scan is finished.
+        """
         #Number of files, e.g. "433 photos and videos" or "23 videos".
         #Displayed in the progress bar at the top of the main application
         #window.
@@ -143,6 +155,14 @@ class FileTypeCounter:
                                'filetypes': file_types_present} 
         return (file_count_summary, file_types_present)
         
+    def running_file_count(self):
+        """
+        Displays raw numbers of photos and videos. Displayed as a scan is 
+        occurring. 
+        """
+        return _("scanning (found %(photos)s photos and %(videos)s videos)...") % ({'photos': self.no_photos(),
+                'videos': self.no_videos()})
+        
 class RPDFile:
     """
     Base class for photo or video file, with metadata
